@@ -1,13 +1,15 @@
 package Sys::Info::Driver::Windows::Device;
 use strict;
-use vars qw( $VERSION );
+use warnings;
 
-$VERSION = '0.72';
+our $VERSION = '0.73';
 
 1;
 
 __END__
 
+=pod
+
 =head1 NAME
 
 Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
@@ -18,8 +20,8 @@ Sys::Info::Driver::Windows::Device - Base class for Windows device drivers
 
 =head1 DESCRIPTION
 
-This document describes version C<0.72> of C<Sys::Info::Driver::Windows::Device>
-released on C<3 May 2009>.
+This document describes version C<0.73> of C<Sys::Info::Driver::Windows::Device>
+released on C<14 January 2010>.
 
 Base class for Windows device drivers.
 
@@ -29,16 +31,16 @@ None.
 
 =head1 AUTHOR
 
-Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>
+Burak Gursoy <burak@cpan.org>.
 
 =head1 COPYRIGHT
 
-Copyright 2006-2009 Burak Grsoy. All rights reserved.
+Copyright 2006 - 2010 Burak Gursoy. All rights reserved.
 
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify 
-it under the same terms as Perl itself, either Perl version 5.10.0 or, 
+it under the same terms as Perl itself, either Perl version 5.10.1 or, 
 at your option, any later version of Perl 5 you may have available.
 
 =cut
